###################
Developer Reference
###################

.. include:: ../CONTRIBUTING.rst

.. include:: ../CODE-OF-CONDUCT.rst

API Reference
=============

Following is the API reference, though it's not well documented. But it's generated! =)

And note that this is just the dob API reference.

- There's also API reference for the other dob components:

  `dob-viewer <https://dob-viewer.readthedocs.io/en/latest/modules.html>`__

  `dob-prompt <https://dob-prompt.readthedocs.io/en/latest/modules.html>`__

  `dob-bright <https://dob-bright.readthedocs.io/en/latest/modules.html>`__

  and `nark <https://nark.readthedocs.io/en/latest/modules.html>`__.

.. include:: modules.rst

**🐹appy 🐹amster 🐹acking!!1**

